package com.jacobs.client;

import com.jacobs.pubsub.Publisher;
import com.jacobs.reservation.EventTypes;
import com.jacobs.reservation.ReservationStatus;
import java.awt.Color;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.util.Observable;
import java.util.Observer;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * The ReservationStatusPanel displays information to the user
 * The ReservationStatusPanel receives the information to be displayed via
 * status events.  The StatusEventSubscriber is responsible for subscribing
 * to the status events.
 *
 * @author Kurt Jacobs
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE.
 *
 * @see com.jacobs.pubsub.Publisher
 * @see com.jacobs.pubsub.Event
 * @see java.util.Observer
 * @see java.util.Observable
 */

class ReservationStatusPanel extends JPanel implements EventTypes
{
    private JLabel mStatusTitleLabel = null;
    private JLabel mStatusLabel = null;
    private static final Font DEFAULT_TITLE_FONT = new Font("Dialog", 1, 12);
    private static final Font DEFAULT_DIALOG_FONT = new Font("Dialog", 0, 12);
    private StatusEventSubscriber mStatusEventSubscriber = null;
    private Publisher mPublisher = null;

    /** The StatusEventSubscriber subscribes to status events and outputs the statuses received to a status control. */
    private final class StatusEventSubscriber implements Observer
    {
        public StatusEventSubscriber()
        {
            mPublisher.subscribe(this, STATUS_EVENT);
        }

        public void update(Observable observable, Object reservationEvent)
        {
            setStatus(((ReservationStatus)reservationEvent).getStatus());
        }
    }


    public ReservationStatusPanel()
    {
        mStatusTitleLabel = new JLabel();
        mStatusLabel = new JLabel();
        initComponents();
        mPublisher = Publisher.getInstance();
        mStatusEventSubscriber = new StatusEventSubscriber();
    }

    private void setStatus(String status)
    {
        mStatusLabel.setText(status);
    }

    /** This method will populate the panel with components. */
    private void initComponents()
    {
        GridBagConstraints statusTitleLabelGridBagConstraints = null;
        GridBagConstraints statusLabelGridBagConstraints = null;
        setLayout(
            new GridBagLayout());
        mStatusTitleLabel.setText("Status :");
        mStatusTitleLabel.setForeground(Color.black);
        mStatusTitleLabel.setFont(DEFAULT_TITLE_FONT);
        statusTitleLabelGridBagConstraints = new GridBagConstraints();
        statusTitleLabelGridBagConstraints.gridx = 0;
        statusTitleLabelGridBagConstraints.gridy = 0;
        statusTitleLabelGridBagConstraints.insets = new Insets(0, 5, 0, 0);
        statusTitleLabelGridBagConstraints.anchor = 18;
        add(mStatusTitleLabel, statusTitleLabelGridBagConstraints);
        mStatusLabel.setFont(DEFAULT_DIALOG_FONT);
        mStatusLabel.setOpaque(false);
        statusLabelGridBagConstraints = new GridBagConstraints();
        statusLabelGridBagConstraints.fill = 2;
        statusLabelGridBagConstraints.insets = new Insets(0, 5, 0, 0);
        statusLabelGridBagConstraints.anchor = 18;
        statusLabelGridBagConstraints.weightx = 1.0D;
        add(mStatusLabel, statusLabelGridBagConstraints);
    }

}

