package com.jacobs.dataSource;

/**
 * The Data class contains a statically defined database used to illustrate
 * an implementation of the Publisher Subscriber Pattern.
 *
 * Note: This in memory database example is provided to facilitate an illustration
 * of a Publisher Subscriber Pattern and does not address the issues associated
 * with database formats etc.
 *
 * @author Kurt Jacobs
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE.
 *
 */

public class Data implements DataConstants
{

    private static String[] [] mData =
        {
        { "EV1","Neil Diamond", "Rock", "10/11/01", "08:45 pm", "105", "20.00" },
        { "EV2","Paul Simon", "Rock", "09/13/01", "07:30 pm", "2140", "15.00"},
        { "EV3","Plano Orchestra", "Classical", "10/14/01", "09:45 pm", "3345", "12.00" },
        { "EV4","Skip Rope", "Folk", "09/04/01", "06:45 pm", "1223", "10.00" },
        { "EV5","Basix", "Gospel", "09/30/01", "06:45 pm", "153", "12.00" },
        { "EV6","Johnny Cash", "Country", "10/20/01", "08:30 pm", "263", "15.00"},
        { "EV7","Boston Pops", "Classical", "10/14/01", "09:45 pm", "3233", "12.00" },
        { "EV8","Willie Nelson", "Country", "09/12/01", "06:15 pm", "0", "15.00" },
        { "EV9","Amy Grant", "Gospel", "09/04/01", "06:45 pm", "153", "14.00" },
        { "EV10","Dwight Yokum", "Country", "10/21/01", "07:30 pm", "363", "12.00"}
    };

    private static Data mDataInstance;

    private Data()
    {
    }

    public static Data getInstance()
    {
        if (mDataInstance == null)
        {
            mDataInstance = new Data();
        }
        return mDataInstance;
    }

    // Return a copy of the data
    public String[] [] getData()
    {
        String[] [] data = new String[mData.length] [DataFieldIDs.NUMBER_FIELDS];
        for (int recordIndex = 0; recordIndex < mData.length; ++recordIndex)
        {
            for (int fieldIndex = 0; fieldIndex < DataFieldIDs.NUMBER_FIELDS; ++fieldIndex)
            {
                data[recordIndex] [fieldIndex] = mData[recordIndex] [fieldIndex];
            }
        }
        return data;
    }
}

