package com.jacobs.dataSource;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.StringTokenizer;

/**
 * The Database class
 *
 * @author Kurt Jacobs
 *
 * Note: This simplistic example of a database is used here to help illustrate
 * an implmentation of a Publisher Subscriber Pattern and does not address the
 * issues such as record locking etc
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE.
 *
 */
public class Database implements DataFieldIDs
{
    private HashMap mFieldMap = null;
    private String[] [] mDatabase = null;

    public Database()
    {
        loadDatabase();
        createDatabaseFieldMap();
    }

    private void loadDatabase()
    {
        mDatabase = Data.getInstance().getData();
    }

    private void createDatabaseFieldMap()
    {
        mFieldMap = new HashMap();
        for (int mapIndex = 0; mapIndex < NUMBER_FIELDS; ++mapIndex)
        {
            mFieldMap.put(FIELD_IDS[mapIndex],
                new Integer(mapIndex));
        }
    }

    private DatabaseRecord createDatabaseRecord(int dataIndex)
    {
        DatabaseRecord databaseRecord = null;
        try
        {
            double value = Double.parseDouble(mDatabase[dataIndex] [PRICE_ID]);
            databaseRecord = new DatabaseRecord(mDatabase[dataIndex] [EVENT_ID], mDatabase[dataIndex] [PERFORMER_ID],
                mDatabase[dataIndex] [GENRE_ID], mDatabase[dataIndex] [DATE_ID], mDatabase[dataIndex] [TIME_ID],
                Integer.parseInt(mDatabase[dataIndex] [TICKET_ID]), Double.parseDouble(mDatabase[dataIndex] [PRICE_ID]));
        }
        catch (NumberFormatException numberFormatException)
        {
            System.err.println("Numeric format error in database");
        }
        return databaseRecord;
    }

    public DatabaseRecord modifyRecord(String recordKey, int ticketsRequested)
    {
        DatabaseRecord record = null;
        int ticketsAvailable = 0;
        int ticketsAfterModified = 0;
        boolean recordFound = false;
        int recordIndex = 0;
        String key = null;
        for (recordIndex = 0; ((recordIndex < mDatabase.length) && (!recordFound)); ++recordIndex)
        {
            key = mDatabase[recordIndex] [EVENT_ID];
            if (key.equals(recordKey))
            {
                recordFound = true;
                try
                {
                    ticketsAvailable = Integer.parseInt(mDatabase[recordIndex] [TICKET_ID]);
                    ticketsAfterModified = ticketsAvailable - ticketsRequested;
                    if (ticketsAfterModified >= 0)
                    {
                        mDatabase[recordIndex] [TICKET_ID] = new Integer(ticketsAfterModified).toString();
                        record = createDatabaseRecord(recordIndex);
                    }
                }
                catch (NumberFormatException numericFormatError)
                {
                    System.err.println("Numeric format error in database");
                }
            }
        }
        return (record);
    }

    public ArrayList findRecords(String queryString)
    {
        StringTokenizer stringTokenizer = null;
        ArrayList matchingRecords = null;
        String searchDatem = null;
        String fieldValue = null;
        int columnIndex = 0;
        int recordIndex = 0;
        int recordsInDatabase = 0;
        ArrayList tokens = null;
        boolean wildcard = false;

        tokens = new ArrayList();
        stringTokenizer = new StringTokenizer(queryString, "=", false);
        while (stringTokenizer.hasMoreTokens())
        {
            tokens.add(stringTokenizer.nextToken());
        }
        columnIndex = ((Integer)mFieldMap.get((String)tokens.get(0))).intValue();
        searchDatem = (String)tokens.get(1);
        if (searchDatem.equals(DataConstants.WILDCARD))
        {
            wildcard = true;
        }
        else
        {
            wildcard = false;
        }
        recordsInDatabase = mDatabase.length;
        matchingRecords = new ArrayList();
        for (recordIndex = 0; recordIndex < recordsInDatabase; ++recordIndex)
        {
            fieldValue = mDatabase[recordIndex] [columnIndex];
            if ((wildcard) || (fieldValue.equalsIgnoreCase(searchDatem)))
            {
                matchingRecords.add(createDatabaseRecord(recordIndex));
            }
        }
        return matchingRecords;
    }
}

