package com.jacobs.dataSource;
/**
 * The DatabaseRecord represents a record of a database.
 *
 * @author Kurt Jacobs
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE.
 *
 */

public class DatabaseRecord
{
    private String mEventID = null;
    private String mPerformer = null;
    private String mGenre = null;
    private String mDate = null;
    private String mTime = null;
    private int mTickets = 0;
    private Currency mPrice = null;

    public DatabaseRecord(String eventID, String performer, String genre, String date, String time, int tickets, double price)
    {
        mEventID = eventID;
        mPerformer = performer;
        mGenre = genre;
        mDate = date;
        mTime = time;
        mTickets = tickets;
        mPrice = new Currency(price);
    }

    public DatabaseRecord(String eventID, String performer, String genre, String date, String time,
        int tickets, Currency price)
        {
            mEventID = eventID;
            mPerformer = performer;
            mGenre = genre;
            mDate = date;
            mTime = time;
            mTickets = tickets;
            mPrice = new Currency(price.doubleValue());
    }

    public void setPerformer(String performer)
    {
        mPerformer = performer;
    }

    public void setGenre(String genre)
    {
        mGenre = genre;
    }

    public void setDate(String date)
    {
        mDate = date;
    }

    public void setTime(String time)
    {
        mTime = time;
    }

    public void setTickets(int tickets)
    {
        mTickets = tickets;
    }

    public void setPrice(double price)
    {
        mPrice = new Currency(price);
    }

    public String getEventID()
    {
        return mEventID;
    }

    public String getPerformer()
    {
        return mPerformer;
    }

    public String getGenre()
    {
        return mGenre;
    }

    public String getDate()
    {
        return mDate;
    }

    public String getTime()
    {
        return mTime;
    }

    public int getTickets()
    {
        return mTickets;
    }

    public Currency getPrice()
    {
        return mPrice;
    }

    public Object clone()
    {
        return new DatabaseRecord(mEventID, mPerformer, mGenre, mDate, mTime, mTickets, mPrice);
    }
}

