package com.jacobs.pubsub;

import java.util.HashMap;
import java.util.Observable;
import java.util.Observer;

/**
 * The Publisher object maintains a list of subscribers who are interested
 * in receiving events of a given type.  The Publisher publishes events
 * to 1->N subscribers
 *
 * @author Kurt Jacobs
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE.
 *
 * @see java.util.Observable;
 * @see java.util.Observer;
 * @see com.jacobs.pubsub.Event
 */

public class Publisher
{
    private static Publisher mInstance = null;
    private HashMap mEventTypes = null;

    private Publisher()
    {
        mEventTypes = new HashMap();
    }

    private class EventObservable extends Observable
    {
        public void notifySubscribers(Event event)
        {
            setChanged();
            notifyObservers(event);
            clearChanged();
        }
    }

    public static Publisher getInstance()
    {
        if (mInstance == null)
        {
            mInstance = new Publisher();
        }
        return mInstance;
    }

    public void subscribe(Observer eventSubscriber, String eventTypeHashKey)
    {
        EventObservable eventType = null;

        if (mEventTypes.containsKey(eventTypeHashKey))
        {
            eventType = (EventObservable)mEventTypes.get(eventTypeHashKey);
            eventType.addObserver(eventSubscriber);
        }
        else
        {
            eventType = new EventObservable();
            eventType.addObserver(eventSubscriber);
            mEventTypes.put(eventTypeHashKey, eventType);
        }
    }

    public void unsubscribe(Observer eventSubscriber, String eventTypeHashKey)
    {
        Observable eventType = null;

        if (mEventTypes.containsKey(eventTypeHashKey))
        {
            eventType = (EventObservable)mEventTypes.get(eventTypeHashKey);
            eventType.deleteObserver(eventSubscriber);
        }
    }

    public void publish(Event reservationEvent)
    {
        String eventTypeHashKey = null;
        EventObservable eventType = null;

        eventTypeHashKey = reservationEvent.getEventType();
        eventType = (EventObservable)mEventTypes.get(eventTypeHashKey);
        eventType.notifySubscribers(reservationEvent);
    }
}

