package com.jacobs.reservation;

/**
 * Tne EventTypes interface contains all the event types necessary for
 * this reservation system.  A subscriber can specify which event type
 * that it would like to subscribe via these event definitions.
 *
 * <pre>
 * Usage:
 *
 *   private final class EventSubscriber implements Observer
 *   {
 *       public StatusEventSubscriber()
 *       {
 *           Publisher.getInstance().subscribe(this, STATUS_EVENT);
 *       }
 *   ...
 *   }
 * </pre>
 *
 * @author Kurt Jacobs
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE.
 *
 */

public interface EventTypes
{
    String QUERY_RESPONSE_EVENT = "QueryResponse";
    String DATA_UPDATE_EVENT = "DataUpdate";
    String STATUS_EVENT = "Status";
    String RESERVATION_CONFIRMATION_EVENT = "ReservationConfirmation";
    String QUERY_REQUEST_EVENT = "QueryRequest";
    String TICKETS_AVAILABLE_EVENT = "TicketsAvailable";
    String TICKET_REQUEST_EVENT = "TicketRequest";
}
