package com.jacobs.reservation;

import com.jacobs.dataSource.Currency;
import com.jacobs.pubsub.Event;

/**
 * The ReservationConfirmation event is published as a result of a reservation
 * have been successfully completed.
 *
 * @author Kurt Jacobs
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE.
 *
 */

public class ReservationConfirmation extends Event
{
    private long mConfirmationID = 0;
    private int mTicketsPurchased = 0;
    private String mEventDescription = null;
    private String mDate = null;
    private String mTime = null;
    private Currency mPrice = null;

    public ReservationConfirmation()
    {
        setEventType(EventTypes.RESERVATION_CONFIRMATION_EVENT);
    }

    public void setConfirmationID(long confirmationID)
    {
        mConfirmationID = confirmationID;
    }

    public void setDate(String date)
    {
        mDate = date;
    }

    public void setTime(String time)
    {
        mTime = time;
    }

    public void setTicketsPurchased(int ticketsPurchased)
    {
        mTicketsPurchased = ticketsPurchased;
    }

    public void setPricePerTicket(Currency price)
    {
        mPrice = price;
    }

    public void setEventDescription(String eventDescription)
    {
        mEventDescription = eventDescription;
    }

    public String getConfirmationSummary()
    {
        StringBuffer summaryBuffer = new StringBuffer();
        summaryBuffer.append("Confirmation ID: ");
        summaryBuffer.append(mConfirmationID);
        summaryBuffer.append("\nEvent: ");
        summaryBuffer.append(mEventDescription);
        summaryBuffer.append("\nDate: ");
        summaryBuffer.append(mDate);
        summaryBuffer.append("\nTime: ");
        summaryBuffer.append(mTime);
        summaryBuffer.append("\nTicket price: ");
        summaryBuffer.append(mPrice);
        summaryBuffer.append("\nTickets purchased: ");
        summaryBuffer.append(mTicketsPurchased);
        summaryBuffer.append("\nTotal cost: ");
        summaryBuffer.append(
            new Currency(mPrice.doubleValue() * mTicketsPurchased));

        return summaryBuffer.toString();
    }

}

