package com.jacobs.reservation;

import com.jacobs.pubsub.Event;

 
/**
 * The ReservationTicketsAvailable event provides information in regard to
 * how many tickets are available for a particluar event.  This information
 * can be used by subscribers to limit a user's ticket request to a value
 * that is equal to or less than the number of tickets available for an
 * event.
 *
 * @author Kurt Jacobs
 *
 * Permission is hereby granted to use, copy, modify and/or distribute
 * this software for commercial and non-commercial purposes.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT WARRANTY. ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE.
 *
 */

public class ReservationTicketsAvailable extends Event
{
    private String mRecordKey = null;
    private int mTicketsAvailable = 0;

    public ReservationTicketsAvailable(String recordKey, int ticketsAvailable)
    {
        setEventType(EventTypes.TICKETS_AVAILABLE_EVENT);
        mRecordKey = recordKey;
        mTicketsAvailable = ticketsAvailable;
    }

    public String getRecordKey()
    {
        return mRecordKey;
    }

    public int getAvailableTickets()
    {
        return mTicketsAvailable;
    }

}

